@@ -106,4 +106,6 @@ class Iam(Blueprint):
 if __name__ == "__main__":
     from runway.context import CfnginContext
 
-    print(Iam("test", CfnginContext(parameters={"namespace": "test"})).to_json())
+    print(  # noqa: T001
+        Iam("test", CfnginContext(parameters={"namespace": "test"})).to_json()
+    )
