@@ -99,7 +99,7 @@ class AuthAtEdge(StaticSite):
         if self.directory_index_specified:
             index_rewrite = self._get_index_rewrite_role_function_and_version()
             lambda_function_associations = self.get_directory_index_lambda_association(
-                lambda_function_associations, index_rewrite["version"]
+                lambda_function_associations, index_rewrite.get("version", "")
             )
 
         # Auth@Edge Lambdas
@@ -208,8 +208,8 @@ class AuthAtEdge(StaticSite):
 
         self.template.add_output(
             Output(
-                "Lambda%sArn" % title,
-                Description="Arn For the %s Lambda Function" % title,
+                f"Lambda{title}Arn",
+                Description=f"Arn For the {title} Lambda Function",
                 Value=lamb.get_att("Arn"),
             )
         )
@@ -336,7 +336,7 @@ class AuthAtEdge(StaticSite):
             ],
             "DefaultCacheBehavior": cloudfront.DefaultCacheBehavior(
                 AllowedMethods=["GET", "HEAD"],
-                Compress=True,
+                Compress=self.variables.get("Compress", True),
                 DefaultTTL="86400",
                 ForwardedValues=cloudfront.ForwardedValues(QueryString=True),
                 LambdaFunctionAssociations=default_cache_behavior_lambdas,
