@@ -41,8 +41,8 @@ class DefaultLookup(LookupHandler):
             env_var_name, default_val = value.split("::", 1)
         except ValueError:
             raise ValueError(
-                "Invalid value for default: %s. Must be in "
-                "<env_var>::<default value> format." % value
+                f"Invalid value for default: {value}. Must be in "
+                "<env_var>::<default value> format."
             ) from None
 
         if context and env_var_name in context.parameters:
