@@ -145,7 +145,8 @@ class BucketLister:
             contents = page.get("Contents", [])
             for content in contents:
                 source_path = bucket + "/" + content.get("Key", "")
-                content["LastModified"] = self._date_parser(content["LastModified"])
+                if "LastModified" in content:
+                    content["LastModified"] = self._date_parser(content["LastModified"])
                 yield source_path, content
 
 
@@ -952,12 +953,9 @@ def uni_print(statement: str, out_file: Optional[TextIO] = None) -> None:
     try:
         out_file.write(statement)
     except UnicodeEncodeError:
-        print("caught")
         new_encoding = getattr(out_file, "encoding", "ascii")
-        print(f"new_encoding: {new_encoding}")
         if not new_encoding:
             new_encoding = "ascii"
-        print(f"new_encoding: {new_encoding}")
         new_statement = statement.encode(new_encoding, "replace").decode(new_encoding)
         out_file.write(new_statement)
     out_file.flush()
