@@ -80,13 +80,6 @@ class StaticSite(RunwayModule):
         self._ensure_cloudfront_with_auth_at_edge()
         self._ensure_correct_region_with_auth_at_edge()
 
-    def plan(self) -> None:
-        """Create website CFN module and run CFNgin.diff."""
-        if self.parameters:
-            self._setup_website_module(command="plan")
-        else:
-            self.logger.info("skipped; environment required but not defined")
-
     def deploy(self) -> None:
         """Create website CFN module and run CFNgin.deploy."""
         if self.parameters:
@@ -125,6 +118,17 @@ class StaticSite(RunwayModule):
         else:
             self.logger.info("skipped; environment required but not defined")
 
+    def init(self) -> None:
+        """Run init."""
+        LOGGER.warning("init not currently supported for %s", self.__class__.__name__)
+
+    def plan(self) -> None:
+        """Create website CFN module and run CFNgin.diff."""
+        if self.parameters:
+            self._setup_website_module(command="plan")
+        else:
+            self.logger.info("skipped; environment required but not defined")
+
     def _setup_website_module(self, command: str) -> None:
         """Create CFNgin configuration for website module."""
         self.logger.info("generating CFNgin config...")
@@ -186,7 +190,7 @@ class StaticSite(RunwayModule):
                         "args": {
                             "user_pool_arn": self.parameters.user_pool_arn,
                             "aliases": self.parameters.aliases,
-                            "stack_name": "${namespace}-%s-dependencies" % self.name,
+                            "stack_name": f"${{namespace}}-{self.name}-dependencies",
                         },
                     }
                 )
@@ -250,15 +254,15 @@ class StaticSite(RunwayModule):
         # Default parameter name matches build_staticsite hook
         if not self.options.source_hashing.parameter:
             self.options.source_hashing.parameter = f"${{namespace}}-{self.name}-hash"
-        nonce_secret_param = "${namespace}-%s-nonce-secret" % self.name
+        nonce_secret_param = f"${{namespace}}-{self.name}-nonce-secret"
 
         build_staticsite_args: Dict[str, Any] = {
             # ensures yaml.safe_load will work by using JSON to convert objects
             "options": json.loads(self.options.data.json(by_alias=True))
         }
-        build_staticsite_args["artifact_bucket_rxref_lookup"] = (
-            "%s-dependencies::ArtifactsBucketName" % self.name
-        )
+        build_staticsite_args[
+            "artifact_bucket_rxref_lookup"
+        ] = f"{self.name}-dependencies::ArtifactsBucketName"
         build_staticsite_args["options"]["namespace"] = "${namespace}"  # type: ignore
         build_staticsite_args["options"]["name"] = self.name  # type: ignore
         build_staticsite_args["options"]["path"] = os.path.join(  # type: ignore
@@ -289,7 +293,7 @@ class StaticSite(RunwayModule):
                     "extra_files": [i.dict() for i in self.options.extra_files],
                     "cf_disabled": site_stack_variables["DisableCloudFront"],
                     "distribution_id": f"${{cfn ${{namespace}}-{self.name}.CFDistributionId"
-                    "::default=undefined}}",
+                    "::default=undefined}",
                     "distribution_domain": f"${{cfn ${{namespace}}-{self.name}."
                     "CFDistributionDomainName::default=undefined}}",
                 },
@@ -321,7 +325,7 @@ class StaticSite(RunwayModule):
             for i in [
                 self.options.source_hashing.parameter,
                 nonce_secret_param,
-                "%sextra" % self.options.source_hashing.parameter,
+                f"{self.options.source_hashing.parameter}extra",
             ]
         ]
 
@@ -387,7 +391,7 @@ class StaticSite(RunwayModule):
             "pre_deploy": pre_deploy,
             "stacks": {
                 self.name: {
-                    "class_path": "runway.blueprints.staticsite.%s" % class_path,
+                    "class_path": f"runway.blueprints.staticsite.{class_path}",
                     "variables": site_stack_variables,
                 }
             },
@@ -425,6 +429,7 @@ class StaticSite(RunwayModule):
     def _get_site_stack_variables(self) -> Dict[str, Any]:
         site_stack_variables: Dict[str, Any] = {
             "Aliases": [],
+            "Compresss": self.parameters.compress,
             "DisableCloudFront": self.parameters.cf_disable,
             "RewriteDirectoryIndex": self.parameters.rewrite_directory_index or "",
             "RedirectPathSignIn": "${default staticsite_redirect_path_sign_in::/parseauth}",
@@ -442,9 +447,9 @@ class StaticSite(RunwayModule):
             site_stack_variables["AcmCertificateArn"] = self.parameters.acmcert_arn
 
         if self.parameters.enable_cf_logging:
-            site_stack_variables["LogBucketName"] = (
-                "${rxref %s-dependencies::AWSLogBucketName}" % self.name
-            )
+            site_stack_variables[
+                "LogBucketName"
+            ] = f"${{rxref {self.name}-dependencies::AWSLogBucketName}}"
 
         if self.parameters.auth_at_edge:
             self._ensure_auth_at_edge_requirements()
@@ -503,14 +508,14 @@ class StaticSite(RunwayModule):
         if self.parameters.create_user_pool:
             args[
                 "created_user_pool_id"
-            ] = "${rxref %s-dependencies::AuthAtEdgeUserPoolId}" % (self.name)
+            ] = f"${{rxref {self.name}-dependencies::AuthAtEdgeUserPoolId}}"
 
         return args
 
     def _get_domain_updater_variables(self) -> Dict[str, str]:
         return {
-            "client_id_output_lookup": "%s-dependencies::AuthAtEdgeClient" % self.name,
-            "client_id": "${rxref %s-dependencies::AuthAtEdgeClient}" % self.name,
+            "client_id_output_lookup": f"{self.name}-dependencies::AuthAtEdgeClient",
+            "client_id": f"${{rxref {self.name}-dependencies::AuthAtEdgeClient}}",
         }
 
     def _get_lambda_config_variables(
@@ -520,8 +525,8 @@ class StaticSite(RunwayModule):
         required_group: Optional[str] = None,
     ) -> Dict[str, Any]:
         return {
-            "client_id": "${rxref %s-dependencies::AuthAtEdgeClient}" % self.name,
-            "bucket": "${rxref %s-dependencies::ArtifactsBucketName}" % self.name,
+            "client_id": f"${{rxref {self.name}-dependencies::AuthAtEdgeClient}}",
+            "bucket": f"${{rxref {self.name}-dependencies::ArtifactsBucketName}}",
             "cookie_settings": site_stack_variables["CookieSettings"],
             "http_headers": site_stack_variables["HttpHeaders"],
             "nonce_signing_secret_param_name": nonce_secret_param,
@@ -538,8 +543,8 @@ class StaticSite(RunwayModule):
         aliases = [add_url_scheme(x) for x in site_stack_variables["Aliases"]]
         return {
             "alternate_domains": aliases,
-            "client_id": "${rxref %s-dependencies::AuthAtEdgeClient}" % self.name,
-            "distribution_domain": "${rxref %s::CFDistributionDomainName}" % name,
+            "client_id": f"${{rxref {self.name}-dependencies::AuthAtEdgeClient}}",
+            "distribution_domain": f"${{rxref {name}::CFDistributionDomainName}}",
             "oauth_scopes": site_stack_variables["OAuthScopes"],
             "redirect_path_sign_in": site_stack_variables["RedirectPathSignIn"],
             "redirect_path_sign_out": site_stack_variables["RedirectPathSignOut"],
